### Name: runifInterface
### Title: Functions for using runif() and rnorm() with randtoolbox
###   generators
### Aliases: runifInterface set.generator put.description get.description
### Keywords: distribution

### ** Examples

RNGkind() # [1] "Mersenne-Twister" "Inversion"   

#parameters for Park Miller congruential generator
paramParkMiller <- c(mod=2^31-1, mult=16807, incr=0)
set.generator(name="congruRand", parameters=paramParkMiller, seed=1)

RNGkind() # [1] "user-supplied" "Inversion"

#description of the RNG set by set.generator(), i.e. Park Miller
print(ParkMiller <- get.description())

#generate 10 random points from the Park-Miller sequence
x1 <- runif(10)

#the seed has changed
get.description()

# the Knuth Lewis RNG
paramKnuthLewis <- c(mod="4294967296", mult="1664525", incr="1013904223")
set.generator(name="congruRand", parameters= paramKnuthLewis, seed=1)

#description of the current RNG, i.e. Knuth Lewis
KLwithseed1 <- get.description()

x2 <- runif(10)

#reinitiate the RNG setting
put.description(ParkMiller)

#the same as x1
x1 == runif(10)

#set WELL RNGs
set.generator("WELL", seed=12345, order=1024, version="a")
get.description()

#get back to the original R setting
set.generator("default")
RNGkind()




